"""
ML Sniff - Automatic Machine Learning Problem Detection

A Python package that automatically detects the type of machine learning problem
from CSV files or pandas DataFrames.
"""

from .sniffer import Sniffer

__version__ = "0.1.0"
__author__ = "ML Sniff Team"
__email__ = "info@ml-sniff.com"

__all__ = ["Sniffer"] 